@@ -10,7 +10,7 @@ plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'))
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
 plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h')
 
-## ---- message=FALSE, fig.width=3.4, fig.height=5.1-----------------------
+## ---- message=FALSE, fig.width=3.9, fig.height=5.1-----------------------
 plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), ncol = 1, align = 'v')
 
 ## ---- message=FALSE, fig.width=4.25, fig.height=5.1----------------------
@@ -39,13 +39,17 @@ plot_grid(g.iris, g.mpg, labels = c('A', 'B'), ncol = 1)
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
 plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', label_size = 12)
 
+## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
+plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', label_size = 12,
+          hjust = -1, vjust = 2.5 )
+
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
 plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', rel_widths = c(1, 1.3))
 
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
-plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', rel_widths = c(1, 1.3), scale = .95)
+plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', rel_widths = c(1, 1.3), scale = 0.95)
 
 ## ---- message=FALSE, fig.width=7.65, fig.height=5.1----------------------
 bottom_row <- plot_grid(plot.mpg, plot.diamonds, labels = c('B', 'C'), align = 'h', rel_widths = c(1, 1.3))
-plot_grid(plot.iris, bottom_row, labels = c('A', ''), ncol = 1, rel_heights = c(1, 1.2), scale = 0.95)
+plot_grid(plot.iris, bottom_row, labels = c('A', ''), ncol = 1, rel_heights = c(1, 1.2))
 
